==> scala-k8s-objects_2.12-0.3.0-sources.jar: io/k8s/api/apiserverinternal/v1alpha1/StorageVersion.scala <==
package io.k8s.api.apiserverinternal.v1alpha1

import dev.hnaderi.k8s._
import dev.hnaderi.k8s.utils._

/** Storage version of a specific resource. */
final case class StorageVersion(
  status : io.k8s.api.apiserverinternal.v1alpha1.StorageVersionStatus,
  spec : io.k8s.api.apiserverinternal.v1alpha1.StorageVersionSpec,
  metadata : Option[io.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta] = None
) extends KObject {
  protected val _resourceKind = ResourceKind("internal.apiserver.k8s.io", "StorageVersion", "v1alpha1")


  /** Returns a new data with status set to new value */
  def withStatus(value: io.k8s.api.apiserverinternal.v1alpha1.StorageVersionStatus) : StorageVersion = copy(status = value)
  /** transforms status to result of function */
  def mapStatus(f: io.k8s.api.apiserverinternal.v1alpha1.StorageVersionStatus => io.k8s.api.apiserverinternal.v1alpha1.StorageVersionStatus) : StorageVersion = copy(status = f(status))

  /** Returns a new data with spec set to new value */
  def withSpec(value: io.k8s.api.apiserverinternal.v1alpha1.StorageVersionSpec) : StorageVersion = copy(spec = value)
  /** transforms spec to result of function */
  def mapSpec(f: io.k8s.api.apiserverinternal.v1alpha1.StorageVersionSpec => io.k8s.api.apiserverinternal.v1alpha1.StorageVersionSpec) : StorageVersion = copy(spec = f(spec))

  /** Returns a new data with metadata set to new value */
  def withMetadata(value: io.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta) : StorageVersion = copy(metadata = Some(value))
  /** if metadata has a value, transforms to the result of function*/
  def mapMetadata(f: io.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta => io.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta) : StorageVersion = copy(metadata = metadata.map(f))

  override def foldTo[T : Builder] : T = StorageVersion.encoder[T].apply(this)
}

object StorageVersion {

    implicit def encoder[T](implicit builder : Builder[T]) : Encoder[io.k8s.api.apiserverinternal.v1alpha1.StorageVersion, T] = new Encoder[io.k8s.api.apiserverinternal.v1alpha1.StorageVersion, T] {
        def apply(o: io.k8s.api.apiserverinternal.v1alpha1.StorageVersion) : T = {
          val obj = ObjectWriter[T]()
          obj
            .write("status", o.status)
            .write("spec", o.spec)
            .write("metadata", o.metadata)
            .write("kind", o.kind)
            .write("apiVersion", o.apiVersion)
            .build
        }
    }

    implicit def decoderOf[T : Reader] : Decoder[T, StorageVersion] = new Decoder[T, StorageVersion] {
      def apply(t: T): Either[String, StorageVersion] = for {
          obj <- ObjectReader(t)
          status <- obj.read[io.k8s.api.apiserverinternal.v1alpha1.StorageVersionStatus]("status")
          spec <- obj.read[io.k8s.api.apiserverinternal.v1alpha1.StorageVersionSpec]("spec")
          metadata <- obj.readOpt[io.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta]("metadata")
      } yield StorageVersion (
          status = status,
          spec = spec,
          metadata = metadata
        )
    }
}

==> scala-k8s-objects_2.13-0.5.1-sources.jar: io/k8s/api/apiserverinternal/v1alpha1/StorageVersion.scala <==
package io.k8s.api.apiserverinternal.v1alpha1

import dev.hnaderi.k8s._
import dev.hnaderi.k8s.utils._

/** Storage version of a specific resource. */
final case class StorageVersion(
  status : io.k8s.api.apiserverinternal.v1alpha1.StorageVersionStatus,
  spec : io.k8s.api.apiserverinternal.v1alpha1.StorageVersionSpec,
  metadata : Option[io.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta] = None
) extends KObject {
  protected val _resourceKind = ResourceKind("internal.apiserver.k8s.io", "StorageVersion", "v1alpha1")


  /** Returns a new data with status set to new value */
  def withStatus(value: io.k8s.api.apiserverinternal.v1alpha1.StorageVersionStatus) : StorageVersion = copy(status = value)
  /** transforms status to result of function */
  def mapStatus(f: io.k8s.api.apiserverinternal.v1alpha1.StorageVersionStatus => io.k8s.api.apiserverinternal.v1alpha1.StorageVersionStatus) : StorageVersion = copy(status = f(status))

  /** Returns a new data with spec set to new value */
  def withSpec(value: io.k8s.api.apiserverinternal.v1alpha1.StorageVersionSpec) : StorageVersion = copy(spec = value)
  /** transforms spec to result of function */
  def mapSpec(f: io.k8s.api.apiserverinternal.v1alpha1.StorageVersionSpec => io.k8s.api.apiserverinternal.v1alpha1.StorageVersionSpec) : StorageVersion = copy(spec = f(spec))

  /** Returns a new data with metadata set to new value */
  def withMetadata(value: io.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta) : StorageVersion = copy(metadata = Some(value))
  /** if metadata has a value, transforms to the result of function*/
  def mapMetadata(f: io.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta => io.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta) : StorageVersion = copy(metadata = metadata.map(f))

  override def foldTo[T : Builder] : T = StorageVersion.encoder.apply(this)
}

object StorageVersion {

    implicit val encoder : Encoder[io.k8s.api.apiserverinternal.v1alpha1.StorageVersion] = new Encoder[io.k8s.api.apiserverinternal.v1alpha1.StorageVersion] {
        def apply[T : Builder](o: io.k8s.api.apiserverinternal.v1alpha1.StorageVersion) : T = {
          val obj = ObjectWriter[T]()
          obj
            .write("status", o.status)
            .write("spec", o.spec)
            .write("metadata", o.metadata)
            .write("kind", o.kind)
            .write("apiVersion", o.apiVersion)
            .build
        }
    }

    implicit val decoder: Decoder[StorageVersion] = new Decoder[StorageVersion] {
      def apply[T : Reader](t: T): Either[String, StorageVersion] = for {
          obj <- ObjectReader(t)
          status <- obj.read[io.k8s.api.apiserverinternal.v1alpha1.StorageVersionStatus]("status")
          spec <- obj.read[io.k8s.api.apiserverinternal.v1alpha1.StorageVersionSpec]("spec")
          metadata <- obj.readOpt[io.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta]("metadata")
      } yield StorageVersion (
          status = status,
          spec = spec,
          metadata = metadata
        )
    }
}
